Index: /main/kofacustom.nigeria/trunk/src/kofacustom/nigeria/students/viewlets.py
===================================================================
--- /main/kofacustom.nigeria/trunk/src/kofacustom/nigeria/students/viewlets.py	(revision 9376)
+++ /main/kofacustom.nigeria/trunk/src/kofacustom/nigeria/students/viewlets.py	(revision 9377)
@@ -228,12 +228,12 @@
     download_name = u'alr_scan'
 
-# Certificate 
+# JAMB Letter/Certificate
 
 class CertificateDisplay(FileDisplay):
     """Certificate display viewlet.
     """
     grok.order(9)
-    label = _(u'Certificate')
-    title = _(u'Certificate')
+    label = _(u'JAMB Letter/Certificate')
+    title = _(u'JAMB Letter/Certificate')
     download_name = u'cert'
 
@@ -242,14 +242,14 @@
 
 class CertificateUpload(FileUpload):
     """Certificate upload viewlet.
     """
     grok.order(9)
-    label = _(u'Certificate')
-    title = _(u'Certificate Scan')
+    label = _(u'JAMB Letter/Certificate')
+    title = _(u'JAMB Letter/Certificate Scan')
     mus = 1024 * 150
     download_name = u'cert'
 
 class CertificateImage(Image):
     """Renders Certificate scan.
     """
     grok.name('cert')
@@ -388,6 +388,6 @@
     """
     grok.order(14)
-    label = _(u'Referee Letter')
-    title = _(u'Referee Letter')
+    label = _(u'Guarantor/Referee Letter')
+    title = _(u'Guarantor/Referee Letter')
     download_name = u'ref_let'
 
@@ -399,6 +399,6 @@
     """
     grok.order(14)
-    label = _(u'Referee Letter')
-    title = _(u'Referee Letter Scan')
+    label = _(u'Guarantor/Referee Letter')
+    title = _(u'Guarantor/Referee Letter Scan')
     mus = 1024 * 150
     download_name = u'ref_let'
@@ -480,5 +480,5 @@
     download_name = u'ref_let3'
 
 # Statutory Declaration of Good Conduct
 
 class StatutoryDeclarationDisplay(FileDisplay):
@@ -486,6 +486,6 @@
     """
     grok.order(17)
-    label = _(u'Statutory Declaration of Good Conduct')
-    title = _(u'Statutory Declaration of Good Conduct')
+    label = _(u'Affidavit of Good Conduct')
+    title = _(u'Affidavit of Good Conduct')
     download_name = u'stat_dec'
 
@@ -497,15 +497,43 @@
     """
     grok.order(17)
-    label = _(u'Statutory Declaration of Good Conduct')
-    title = _(u'Statutory Declaration of Good Conduct Scan')
+    label = _(u'Affidavit of Good Conduct')
+    title = _(u'Affidavit of Good Conduct Scan')
     mus = 1024 * 150
     download_name = u'stat_dec'
 
 class StatutoryDeclarationImage(Image):
     """Renders Statutory Declaration of Good Conduct scan.
     """
     grok.name('stat_dec')
     download_name = u'stat_dec'
 
+# Affidavit of Non-Menbership of Secret Cults
+
+class SecrCultsStatementDisplay(FileDisplay):
+    """Affidavit of Non-Menbership of Secret Cults display viewlet.
+    """
+    grok.order(18)
+    label = _(u'Affidavit of Non-Menbership of Secret Cults')
+    title = _(u'Affidavit of Non-Menbership of Secret Cults')
+    download_name = u'secr_cults'
+
+class SecrCultsStatementSlip(SecrCultsStatementDisplay):
+    grok.view(ExportPDFClearanceSlipPage)
+
+class SecrCultsStatementUpload(FileUpload):
+    """Affidavit of Non-Menbership of Secret Cults upload viewlet.
+    """
+    grok.order(18)
+    label = _(u'Affidavit of Non-Menbership of Secret Cults')
+    title = _(u'Affidavit of Non-Menbership of Secret Cults Scan')
+    mus = 1024 * 150
+    download_name = u'secr_cults'
+
+class ResultStatementImage(Image):
+    """Renders Affidavit of Non-Menbership of Secret Cults scan.
+    """
+    grok.name('secr_cults')
+    download_name = u'secr_cults'
+
 # Letter of Admission (PG Students only)
 
@@ -513,5 +541,5 @@
     """Letter of Admission display viewlet.
     """
-    grok.order(18)
+    grok.order(19)
     label = _(u'Letter of Admission')
     title = _(u'Letter of Admission')
@@ -524,5 +552,5 @@
     """Letter of Admission upload viewlet.
     """
-    grok.order(18)
+    grok.order(19)
     label = _(u'Letter of Admission')
     title = _(u'Letter of Admission Scan')
@@ -228,12 +228,12 @@
 
 class CertificateDisplay(FileDisplay):
-    """Certificate display viewlet.
+    """JAMB Letter/Certificate display viewlet.
     """
     grok.order(9)
@@ -242,14 +242,14 @@
 
 class CertificateUpload(FileUpload):
-    """Certificate upload viewlet.
+    """JAMB Letter/Certificate upload viewlet.
     """
     grok.order(9)
@@ -242,14 +242,14 @@
 
 class CertificateImage(Image):
-    """Renders Certificate scan.
+    """Renders JAMB Letter/Certificate scan.
     """
     grok.name('cert')
@@ -480,5 +480,5 @@
     download_name = u'ref_let3'
 
-# Statutory Declaration of Good Conduct
+# Affidavit (former Statutory Declaration) of Good Conduct
 
 class StatutoryDeclarationDisplay(FileDisplay):
@@ -497,15 +497,43 @@
 
 class StatutoryDeclarationImage(Image):
-    """Renders Statutory Declaration of Good Conduct scan.
+    """Renders Affidavit of Good Conduct scan.
     """
     grok.name('stat_dec')
